Update of /cvsroot/fink/dists/10.4/stable/main/finkinfo/editors
In directory 
sc8-pr-cvs17.sourceforge.net:/tmp/cvs-serv12977/10.4/stable/main/finkinfo/editors

Added Files:
        emacs22-carbon.info emacs22-carbon.patch 
Log Message:
Moved from unstable. Now emacsen is available in 10.5/stable.

--- NEW FILE: emacs22-carbon.info ---
Package: emacs22-carbon
Version: 22.1
# I committed 1001 in 10.3 and 1 in 10.4 by mistake; add 2000 to Revision.
Revision: 3003
BuildDepends: libncurses5 (>= 5.4-20041023-1006), fink (>= 0.24.2)
Depends: emacsen-common, ncurses (>= 5.4-20041023-1006), libncurses5-shlibs (>= 
5.4-20041023-1006), passwd, macosx
Provides: emacsen
Source: mirror:gnu:emacs/emacs-%v.tar.gz
Source-MD5: 6949df37caec2d7a2e0eee3f1b422726
Source2: 
http://downloads.sourceforge.jp/macemacsjp/26030/inline_patch-1.0.3.tar.gz
Source2-MD5: cd29ca429a1d361de19320aace66c60d
Source3: 
http://downloads.sourceforge.jp/macemacsjp/26111/transparency-3.1.0.tar.gz
Source3-MD5: e6eabf1735c0e8268ee2cadd33f7234a
Source4: 
http://downloads.sourceforge.jp/macemacsjp/26400/fixed-width-fontset.1.2.0.tar.gz
Source4-MD5: f1235b505bd51bf306a10fe30f2a5cc8
Source5: http://downloads.sourceforge.jp/macemacsjp/17718/mac-functions.patch
Source5Rename: mac-functions-20051116.patch
Source5-MD5: 6d122157a8c1c98b2b569e07da545206
Source6: http://downloads.sourceforge.jp/macemacsjp/23457/utf-8m.el
Source6Rename: utf-8m-20070105.el
Source6-MD5: 779d181fa3b5ba5b2b30f1ec8aa995e7
Source7: http://downloads.sourceforge.jp/macemacsjp/24135/hide_menubar.tar.gz
Source7Rename: hide_menubar-0.2.0.tar.gz
Source7-MD5: df47c265c220ed6ea4aaf4f5887772fb
Description: Flexible real-time text editor, Aqua native
DocFiles: <<
  AUTHORS COPYING README mac/README:mac.README
  ../transparency*/readme:transparency.readme
  ../fixed-width-fontset.*/readme:fixed-width-fontset.readme
  ../fixed-width-fontset.*/readme.ja:fixed-width-fontset.readme.ja
<<
ConfFiles: %p/var/games/%n/tetris-scores %p/var/games/%n/snake-scores
AppBundles: finktmp/mac/Emacs22.app

PatchScript: <<
#!/bin/sh -ev

# Remove CVS date from version number (%v) and append '-carbon' suffix
v=`echo "%v"|sed 's/\.cvs.*$//'`-carbon

sed -e 's|@PREFIX@|%p|g' \
    -e 's|@EMACS-FLAVOR@|%n|g' \
    -e "s|@EMACS-VERSION@|$v|g" \
    %a/%n.patch | patch -p1
/usr/bin/patch -p0 -i ../inline_patch-*/emacs-inline.patch
/usr/bin/patch -p0 -i ../transparency*/transparency*.patch
mkdir finktmp
cp ../fixed-width-fontset.*/carbon-font.el 
../fixed-width-fontset.*/fixed-width-fontset.el finktmp
/usr/bin/patch -p0 -i ../mac-functions-*.patch
cp ../utf-8m-*.el finktmp/utf-8m.el
/usr/bin/patch -p1 -i ../hide_menubar.patch
<<

SetMAKEFLAGS: -j1
SetCPPFLAGS: -DUSE_ATSUI -DUSE_MAC_TSM
SetCFLAGS: -fconstant-cfstrings -Os
ConfigureParams: --build=%m-apple-darwin`uname -r|sed 's/\\..*//'` 
--infodir='${prefix}/share/info' --mandir='${prefix}/share/man' 
--libexecdir='${prefix}/lib' --with-carbon --enable-carbon-appdir= --without-x 
--without-gif --without-toolkit-scroll-bars
CompileScript: <<
#!/bin/sh -ev

# Remove CVS date from version number (%v) and append '-carbon' suffix
v=`echo "%v"|sed 's/\.cvs.*$//'`-carbon

set +v
case `uname -r` in
    7.*)
    QTver="`/usr/lib/plistread 
/System/Library/Frameworks/QuickTime.framework/Resources/version.plist 
CFBundleShortVersionString`"
    case ${QTver} in
        7.0.4)
        echo "****************  ERROR  ****************" >&2
        echo 'QuickTime 7.0.4 breaks the build on 10.3.' >&2
        echo 'Get 7.0.1 reinstaller and downgrade QuickTime.' >&2
        echo 
'http://www.apple.com/support/downloads/quicktime701reinstallerforquicktime704.html'
 >&2
        echo "****************  ERROR  ****************" >&2
        exit 1
        ;;
        7.2* | 7.3* | 7.4*)
        echo "****************  ERROR  ****************" >&2
        echo "QuickTime ${QTver} breaks the build on 10.3." >&2
        echo "Get 7.1.6 installer and downgrade QuickTime." >&2
        echo "****************  ERROR  ****************" >&2
        exit 1
        ;;
    esac
    ;;
esac
set -v
./configure %c
# Sync .elc's with patched .el's
(cd src && make bootstrap) || exit
(cd lisp && make recompile EMACS=../src/bootstrap-emacs) || exit
# Compile emacs with new *.elc
make

/usr/bin/find mac/Emacs.app ! -path "*/CVS/*" ! -name CVS ! -name .cvsignore > 
app.list
/usr/bin/cpio -pdL finktmp < app.list
mv finktmp/mac/Emacs.app finktmp/mac/Emacs22.app
EMACSLOADPATH=$PWD/finktmp:$PWD/lisp src/emacs -batch --no-init-file 
--no-site-file --multibyte -f batch-byte-compile 01carbon-emacs.el finktmp/*.el
<<

InstallScript: <<
#!/bin/sh -ev

# Remove CVS date from version number (%v) and append '-carbon' suffix
v=`echo "%v"|sed 's/\.cvs.*$//'`-carbon

# Install Everything (except Emacs.app)
make prefix=%i install

# Move some files to avoid conflicts with other emacsen
for f in %i/share/man/man1/{emacs.1,ctags.1,emacsclient.1,etags.1} \
        %i/bin/{ctags,emacsclient,etags} \
        %i/bin/{b2m,rcs-checkin,ebrowse,grep-changelog}; do
    mv "$f" "$f.%n"
done

# Wrapper script for the command-line invokation
rm %i/bin/emacs %i/bin/emacs-$v
install -m 755 emacs.bash %i/bin/emacs-$v
ln -s emacs-$v %i/bin/%n
ln -s emacs-$v %i/bin/Emacs22.app

mkdir -p %i/etc/%n/site-start.d
mkdir -p %i/share/%n
mv %i/share/emacs/$v/site-lisp %i/share/%n/
(cd %i/share/emacs/$v; ln -s ../../%n/site-lisp site-lisp) || exit

mv %i/share/info %i/share/info-%n
mkdir -p %i/share/info
mv %i/share/info-%n %i/share/info/%n
rm %i/share/info/%n/dir %i/share/info/%n/dir.old
chmod 755 fix-info mangle-info
./fix-info %i/share/info/%n

rm %i/share/emacs/site-lisp/subdirs.el
install -m 644 finktmp/*.el finktmp/*.elc %i/share/%n/site-lisp
install -m 644 01carbon-emacs.el 01carbon-emacs.elc %i/etc/%n/site-start.d

# Patch Emacs22.app to load %p/bin/init.sh
ebd="finktmp/mac/Emacs22.app/Contents/MacOS/"
mv "$ebd/Emacs" "$ebd/Emacs.bin"
install -m 755 Emacs.finkwrap "$ebd/Emacs"
<<

PostInstScript: <<
# Remove CVS date from version number (%v) and append '-carbon' suffix
v=`echo "%v"|sed 's/\.cvs.*$//'`-carbon
libdir=%p/lib/emacs/$v/%m-apple-darwin`uname -r|sed 's/\\..*//'`

chown games:admin $libdir/update-game-score
chmod 4755 $libdir/update-game-score
chown -R games:admin %p/var/games/%n
mkdir -p %p/etc/lisp/emacs/$v/site-lisp
mkdir -p %p/etc/lisp/emacs/site-lisp

  # Priorities are set to low not to disturb non-carbon emacsen...
update-alternatives --install %p/bin/emacs emacs %p/bin/%n 35 \
        --slave %p/share/man/man1/emacs.1 emacs.1 %p/share/man/man1/emacs.1.%n
update-alternatives --install %p/bin/ctags ctags %p/bin/ctags.%n 35 \
        --slave %p/share/man/man1/ctags.1 ctags.1 %p/share/man/man1/ctags.1.%n
update-alternatives --install %p/bin/etags etags %p/bin/etags.%n 55 \
        --slave %p/share/man/man1/etags.1 etags.1 %p/share/man/man1/etags.1.%n
update-alternatives \
        --install %p/bin/emacsclient emacsclient %p/bin/emacsclient.%n 35 \
        --slave %p/share/man/man1/emacsclient.1 emacsclient.1 \
                                        %p/share/man/man1/emacsclient.1.%n
update-alternatives --install %p/bin/b2m b2m %p/bin/b2m.%n 35
update-alternatives \
        --install %p/bin/rcs-checkin rcs-checkin %p/bin/rcs-checkin.%n 35
update-alternatives --install %p/bin/ebrowse ebrowse %p/bin/ebrowse.%n 35
update-alternatives --install %p/bin/grep-changelog grep-changelog \
                                        %p/bin/grep-changelog.%n 35

# Regiser ourselves with emacsen-common
%p/lib/emacsen-common/emacs-install %n

# Since we're placing our info files in a subdirectory of %p/share/info
# we need to manually add each doc to the info dir-file
# NOTE: list of info docs also present in prerm script and "fixinfo"
#   included in the emacs22-carbon.patch
for file in ada-mode autotype calc ccmode cl dired-x ebrowse ediff efaq \
    eintr elisp emacs emacs-mime erc eshell eudc flymake \
    forms gnus idlwave info message mh-e newsticker org pcl-cvs \
    pgg rcirc reftex sc ses sieve smtpmail speedbar tramp url \
    vip viper widget woman
do
  install-info --infodir=%p/share/info \
        --section "Carbon Emacs" "Carbon Emacs" %p/share/info/%n/${file}
done
<<

PreRmScript: <<
# Remove CVS date from version number (%v) and append '-carbon' suffix
v=`echo "%v"|sed 's/\.cvs.*$//'`-carbon

# Manually remove all of our info docs from the dir-file
for file in ada-mode autotype calc ccmode cl dired-x ebrowse ediff efaq \
    eintr elisp emacs emacs-mime erc eshell eudc flymake \
    forms gnus idlwave info message mh-e newsticker org pcl-cvs \
    pgg rcirc reftex sc ses sieve smtpmail speedbar tramp url \
    vip viper widget woman
do
  install-info --infodir=%p/share/info --remove-exactly %n/${file}
done

if [ $1 != "upgrade" ]; then
  update-alternatives --remove emacs %p/bin/%n
  update-alternatives --remove emacsclient %p/bin/emacsclient.%n
  update-alternatives --remove ctags %p/bin/ctags.%n
  update-alternatives --remove etags %p/bin/etags.%n
  update-alternatives --remove b2m %p/bin/b2m.%n
  update-alternatives --remove rcs-checkin %p/bin/rcs-checkin.%n
  update-alternatives --remove ebrowse %p/bin/ebrowse.%n
  %p/lib/emacsen-common/emacs-remove %n
fi
<<

DescDetail: <<
GNU Emacs is an extensible, customizable, self-documenting real-time
display editor. Through its extensibility, it is actually much more
than an editor. You can use it as a file manager, mail reader, web
browser, and for many other tasks. Some people even use it to control
their coffee machine.

This package installs Carbon port of GNU Emacs, which can natively run
on Mac OS X window system.  Also supports input methods for
international languages.

Use -nw option to use this emacs on terminal.
<<

DescPackaging: <<
This .info file is essentially based on the emacs21 package by:
Christian Swinehart <[EMAIL PROTECTED]>

The first author of this package is:
NAKAHASHI Ichiro <[EMAIL PROTECTED]>

update-alternatives is used for emacs, emacsclient, ctags, etags, b2m
rcs-checkin, ebrowse, and grep-changelog to allow parallel installation 
of emacs22 & xemacs & emacs22-carbon.

Its info files are installed into the emacs22-carbon subdirectory of
<fink-root>/share/info for the same reason.
<<
DescPort: <<
You can lauch emacs22 from Finder, as well as terminal using usual
command line syntax. For this purpose, Emacs22.app is placed on
%p/Applications and will be symlinked to /Applications/Fink. To gain a
better integration with the fink environments, it automatically loads
%p/bin/init.sh at startup.

I don't know why nichiro set $0 to Emacs instead of Emacs.bin.

The patchfile modifies startup.el, and brings in the scripts fix-info and 
mangle-info, in order to implement our emacs packaging system.
<<
DescUsage: <<
You can launch emacs22-carbon, not just by double-clicking, but also by typing
$ emacs22-carbon
or
$ Emacs22.app
in the terminal. In this way, you can pass runtime options to emacs, e.g.
$ emacs22-carbon --no-site-file

If you want to input characters via MacIM in inline style, add your .emacs.el:
(if (eq window-system 'mac)
    (setq default-input-method "MacOSX"))
In addition, if you want to input "Backslash" instead of "Yen Sign", add:
(if (eq window-system 'mac) (progn
    (setq default-input-method "MacOSX")
    (mac-translate-from-yen-to-backslash)))
<<
License: GPL
Maintainer: Todai Fink Team <[EMAIL PROTECTED]>
Homepage: http://www.emacswiki.org/cgi-bin/wiki

--- NEW FILE: emacs22-carbon.patch ---
diff -Naur emacs-22.1.orig/01carbon-emacs.el emacs-22.1/01carbon-emacs.el
--- emacs-22.1.orig/01carbon-emacs.el   1970-01-01 00:00:00.000000000 +0000
+++ emacs-22.1/01carbon-emacs.el        2007-06-08 13:59:50.000000000 +0000
@@ -0,0 +1,13 @@
+(if (eq window-system 'mac)
+  (progn
+    ;; append "PREFIX/sbin" "PREFIX/bin" to exec-path
+    (if (not (member "@PREFIX@/sbin" exec-path))
+       (setq exec-path (append '("@PREFIX@/sbin") exec-path))
+    )
+    (if (not (member "@PREFIX@/bin" exec-path))
+       (setq exec-path (append '("@PREFIX@/bin") exec-path))
+      )
+
+    ;; inline image support
+    (auto-image-file-mode)
+  ))
diff -Naur emacs-22.1.orig/Emacs.finkwrap emacs-22.1/Emacs.finkwrap
--- emacs-22.1.orig/Emacs.finkwrap      1970-01-01 00:00:00.000000000 +0000
+++ emacs-22.1/Emacs.finkwrap   2006-03-06 15:42:52.000000000 +0000
@@ -0,0 +1,3 @@
+#!/bin/bash
+. @PREFIX@/bin/init.sh
+exec -a "$0" "$0.bin" "$@"
diff -Naur emacs-22.1.orig/Makefile.in emacs-22.1/Makefile.in
--- emacs-22.1.orig/Makefile.in 2007-05-14 14:56:28.000000000 +0000
+++ emacs-22.1/Makefile.in      2007-06-07 13:14:37.000000000 +0000
@@ -436,8 +436,7 @@
          && (echo "Copying $${dir} to $${dest}..." ; \
              (cd $${dir}; tar -chf - . ) \
                | (cd $${dest}; umask 022; \
-                   tar -xvf - && cat > /dev/null) || exit 1; \
-             find $${dest} -exec chown $${LOGNAME:-$$USERNAME} {} ';' ;\
+                   tar -xvf - --no-same-owner --no-same-permissions && cat > 
/dev/null) || exit 1; \
              for subdir in `find $${dest} -type d ! -name RCS ! -name CVS 
-print` ; do \
                chmod a+rx $${subdir} ; \
                rm -rf $${subdir}/RCS ; \
@@ -476,8 +475,8 @@
        then \
           echo "Copying etc/DOC-* to $(DESTDIR)${docdir} ..." ; \
           (cd ./etc; tar -chf - DOC*) \
-            |(cd $(DESTDIR)${docdir}; umask 022; tar -xvf - && cat > 
/dev/null) || exit 1; \
-          (cd $(DESTDIR)$(docdir); chown $${LOGNAME:-$$USERNAME} DOC*; chmod 
a+r DOC*; \
+            |(cd $(DESTDIR)${docdir}; umask 022; tar -xvf - --no-same-owner 
--no-same-permissions && cat > /dev/null) || exit 1; \
+          (cd $(DESTDIR)$(docdir); chmod a+r DOC*; \
            if test "`echo DOC-*`" != "DOC-*"; then rm DOC; fi); \
        else true; fi
        -unset CDPATH; \
@@ -488,8 +487,7 @@
        then \
           echo "Copying lisp/*.el and lisp/*.elc to $(DESTDIR)${lispdir} ..." 
; \
           (cd lisp; tar -chf - *.el *.elc) \
-            |(cd $(DESTDIR)${lispdir}; umask 022; tar -xvf - && cat > 
/dev/null) || exit 1; \
-          (cd $(DESTDIR)${lispdir}; find . -exec chown $${LOGNAME:-$$USERNAME} 
{} ';') ; \
+            |(cd $(DESTDIR)${lispdir}; umask 022; tar -xvf - --no-same-owner 
--no-same-permissions && cat > /dev/null) || exit 1; \
        else true; fi
        -unset CDPATH; \
        if [ -n "${GZIP_PROG}" ]; \
diff -Naur emacs-22.1.orig/configure emacs-22.1/configure
--- emacs-22.1.orig/configure   2007-05-25 12:43:29.000000000 +0000
+++ emacs-22.1/configure        2007-06-07 13:14:37.000000000 +0000
@@ -1807,7 +1807,7 @@
 etcdir='${datadir}/emacs/${version}/etc'
 archlibdir='${libexecdir}/emacs/${version}/${configuration}'
 docdir='${datadir}/emacs/${version}/etc'
-gamedir='${localstatedir}/games/emacs'
+gamedir='${localstatedir}/games/@EMACS-FLAVOR@'
 
 gameuser=games
 
@@ -22935,6 +22935,7 @@
 echo "$as_me: error: can't find current emacs version in 
\`${srcdir}/lisp/version.el'." >&2;}
    { (exit 1); exit 1; }; }
 fi
+version="@EMACS-VERSION@"
 
 ### Specify what sort of things we'll be editing into Makefile and config.h.
 ### Use configuration here uncanonicalized to avoid exceeding size limits.
diff -Naur emacs-22.1.orig/emacs.bash emacs-22.1/emacs.bash
--- emacs-22.1.orig/emacs.bash  1970-01-01 00:00:00.000000000 +0000
+++ emacs-22.1/emacs.bash       2006-03-06 15:42:52.000000000 +0000
@@ -0,0 +1,3 @@
+#!/bin/bash
+exec -a "@PREFIX@/Applications/Emacs22.app/Contents/MacOS/Emacs" \
+    "@PREFIX@/Applications/Emacs22.app/Contents/MacOS/Emacs.bin" "$@"
diff -Naur emacs-22.1.orig/fix-info emacs-22.1/fix-info
--- emacs-22.1.orig/fix-info    1970-01-01 00:00:00.000000000 +0000
+++ emacs-22.1/fix-info 2007-06-07 13:22:34.000000000 +0000
@@ -0,0 +1,12 @@
+#!/bin/sh
+
+THE_INFO_PREFIX=$1
+
+for file in ada-mode autotype calc ccmode cl dired-x ebrowse ediff efaq \
+           elisp eintr emacs emacs-mime eshell eudc flymake \
+           forms gnus idlwave info message mh-e newsticker org pcl-cvs \
+           pgg reftex sc ses sieve speedbar tramp vip viper widget \
+           woman smtpmail url rcirc erc
+do
+    ./mangle-info ${THE_INFO_PREFIX}/${file}
+done
diff -Naur emacs-22.1.orig/lisp/startup.el emacs-22.1/lisp/startup.el
--- emacs-22.1.orig/lisp/startup.el     2007-05-14 14:56:29.000000000 +0000
+++ emacs-22.1/lisp/startup.el  2007-06-07 13:14:37.000000000 +0000
@@ -292,6 +292,10 @@
 
 (defvar default-frame-background-mode)
 
+(defconst fink-emacs-flavor '@EMACS-FLAVOR@
+  "A symbol representing the particular fink flavor of emacs running.
+Something like 'emacs20, 'xemacs20, etc.")
+
 (defvar pure-space-overflow nil
   "Non-nil if building Emacs overflowed pure space.")
 
@@ -815,8 +819,20 @@
     ;; Run the site-start library if it exists.  The point of this file is
     ;; that it is run before .emacs.  There is no point in doing this after
     ;; .emacs; that is useless.
+
+    ;; (if site-run-file
+    ;;     (load site-run-file t t))
+
+    ;; Fink version of site-start.
     (if site-run-file
-       (load site-run-file t t))
+        (progn
+          ;; Load all the fink package snippets.
+          ;; It's in here because we want -q to kill it too.
+          (if (load "fink-startup" t t nil)
+              (fink-startup fink-emacs-flavor))
+          ;; Now the normal site file...
+          (load site-run-file t t nil)))
+
 
     ;; Sites should not disable this.  Only individuals should disable
     ;; the startup message.
diff -Naur emacs-22.1.orig/mangle-info emacs-22.1/mangle-info
--- emacs-22.1.orig/mangle-info 1970-01-01 00:00:00.000000000 +0000
+++ emacs-22.1/mangle-info      2006-03-06 15:42:52.000000000 +0000
@@ -0,0 +1,17 @@
+#!/usr/bin/perl -w -i
+
+use English;
+use strict;
+
+$RS = undef;
+
+my $prefix = "@EMACS-FLAVOR@";
+
+my $x = <>;
+if(!($x =~ m/^(\s*START-INFO-DIR-ENTRY\s+\*\s*[^:]+:\s*)\(([^\)]+)\)/mo)) {
+  die "Couldn't find START-INFO-DIR-ENTRY.";
+}
+   
+print ${PREMATCH};
+print "$1($prefix/$2)";
+print ${POSTMATCH};
diff -ruN --exclude '*~' --exclude '*.orig' emacs-22.1/src/unexmacosx.c 
emacs-22.1.patched/src/unexmacosx.c
--- emacs-22.1/src/unexmacosx.c 2007-01-20 23:18:15.000000000 -0500
+++ emacs-22.1.patched/src/unexmacosx.c 2007-11-14 21:44:17.000000000 -0500
@@ -443,15 +443,13 @@
 
   while (num && num_unexec_regions < MAX_UNEXEC_REGIONS)
     {
       /* Subtract the size of trailing null pages from filesize.  It
         can be smaller than vmsize in segment commands.  In such a
-        case, trailing pages are initialized with zeros.  */
-      for (p = ranges->address + ranges->size; p > ranges->address;
-          p -= sizeof (int))
-       if (*(((int *) p)-1))
-         break;
-      filesize = ROUNDUP_TO_PAGE_BOUNDARY (p - ranges->address);
-      assert (filesize <= ranges->size);
+        case, trailing bytes are initialized with zeros.  */
+      for (p = ranges->address + ranges->size; p > ranges->address; p--)
+       if (*(((char *) p)-1))
+         break;
+      filesize = p - ranges->address;
 
       unexec_regions[num_unexec_regions].filesize = filesize;
       unexec_regions[num_unexec_regions++].range = *ranges;
@@ -503,11 +501,19 @@
 {
   int i, n;
   unexec_region_info r;
+  vm_size_t padsize;
 
   qsort (unexec_regions, num_unexec_regions, sizeof (unexec_regions[0]),
         &unexec_regions_sort_compare);
   n = 0;
   r = unexec_regions[0];
+  padsize = r.range.address & (pagesize - 1);
+  if (padsize)
+    {
+      r.range.address -= padsize;
+      r.range.size += padsize;
+      r.filesize += padsize;
+    }
   for (i = 1; i < num_unexec_regions; i++)
     {
       if (r.range.address + r.range.size == unexec_regions[i].range.address
@@ -520,6 +526,17 @@
        {
          unexec_regions[n++] = r;
          r = unexec_regions[i];
+         padsize = r.range.address & (pagesize - 1);
+         if (padsize)
+           {
+             if ((unexec_regions[n-1].range.address
+                  + unexec_regions[n-1].range.size) == r.range.address)
+               unexec_regions[n-1].range.size -= padsize;
+
+             r.range.address -= padsize;
+             r.range.size += padsize;
+             r.filesize += padsize;
+           }
        }
     }
   unexec_regions[n++] = r;
@@ -562,6 +579,11 @@
     case LC_TWOLEVEL_HINTS:
       printf ("LC_TWOLEVEL_HINTS");
       break;
+#ifdef LC_UUID
+    case LC_UUID:
+      printf ("LC_UUID          ");
+      break;
+#endif
     default:
       printf ("unknown          ");
     }


-------------------------------------------------------------------------
@@ -443,15 +443,13 @@
   while (num && num_unexec_regions < MAX_UNEXEC_REGIONS)
     {
-      /* Subtract the size of trailing null pages from filesize.  It
+      /* Subtract the size of trailing null bytes from filesize.  It
         can be smaller than vmsize in segment commands.  In such a
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2008.
http://clk.atdmt.com/MRT/go/vse0120000070mrt/direct/01/
_______________________________________________
Fink-commits mailing list
Fink-commits@lists.sourceforge.net
http://news.gmane.org/gmane.os.apple.fink.cvs

Reply via email to